<?php

namespace Drupal\eca_commerce\EventSubscriber;

use Drupal\commerce_cart\Event\CartEntityAddEvent;
use Drupal\eca\EcaEvents;
use Drupal\eca\Event\BeforeInitialExecutionEvent;
use Drupal\eca\EventSubscriber\EcaBase;
use Drupal\eca_commerce\Plugin\ECA\Event\EcaEvent;

/**
 * eca_commerce event subscriber.
 */
class EcaEventSubscriber extends EcaBase {

  public function onBeforeInitialExecution(BeforeInitialExecutionEvent $before_event): void {
    $event = $before_event->getEvent();
    if ($event instanceof CartEntityAddEvent) {
      $this->tokenService->addTokenData('entity', $event->getEntity());
      $this->tokenService->addTokenData('cart', $event->getCart());
      $this->tokenService->addTokenData('quantity', $event->getQuantity());
      $this->tokenService->addTokenData('commerce_order_item', $event->getOrderItem());
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events = [];
    foreach (EcaEvent::definitions() as $definition) {
      $events[$definition['event_name']][] = ['onEvent'];
    }
    $events[EcaEvents::BEFORE_INITIAL_EXECUTION][] = [
      'onBeforeInitialExecution',
      -100,
    ];
    return $events;
  }

}
